@@ -1749,7 +1749,7 @@ print(x$call)
 cat("\n")
 cat("\nFixed Effects:\n")
 cat("\nCoefficients:\n")
-printCoefmat(x$coefficients, P.value=TRUE, has.Pvalue=TRUE)
+printCoefmat(x$coefficients, P.values=TRUE, has.Pvalue=TRUE)
 cat("\nRandom Effects:\n")
 cat("\nStdDev:\n")
 print(x$StdDev)
